@@ -28,8 +28,10 @@
 #include <locale.h>
 #include <math.h>
 #include <string.h>
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
+
+#include <parser.h>
+#include <xmlmemory.h>
+
 #include "gal/util/e-i18n.h"
 #include "gal/util/e-util.h"
 
